import { CSSProperties, FC, RefAttributes } from 'react';
import { FooterLegendProps } from './FooterLegend';
export interface DialogCommonProps extends RefAttributes<HTMLDivElement> {
    style?: CSSProperties;
    className?: string;
}
export interface DialogButtonProps extends DialogCommonProps, FooterLegendProps {
    /**
     * Enables/disables the focus around the button.
     *
     * @note
     * Default value depends on context, so setting it to `false` will enable it.
     */
    noFocusRing?: boolean;
    /**
     * Disables the button - assigned `on*` methods will not be invoked if clicked.
     *
     * @note
     * Depending on where it is, it might still get focus. In such case it can be
     * partially disabled separately.
     *
     * @see focusable.
     */
    disabled?: boolean;
    /**
     * Enables/disables the navigation based focus on button - you won't be able to navigate to
     * it via the gamepad or keyboard.
     *
     * @note
     * If set to `false`, it still can be clicked and **WILL** become focused until navigated away.
     * Depending on the context of where the button is, even a disabled button can focused.
     */
    focusable?: boolean;
    onClick?(e: MouseEvent): void;
    onPointerDown?(e: PointerEvent): void;
    onPointerUp?(e: PointerEvent): void;
    onPointerCancel?(e: PointerEvent): void;
    onMouseDown?(e: MouseEvent): void;
    onMouseUp?(e: MouseEvent): void;
    onTouchStart?(e: TouchEvent): void;
    onTouchEnd?(e: TouchEvent): void;
    onTouchCancel?(e: TouchEvent): void;
    onSubmit?(e: SubmitEvent): void;
}
export declare const DialogHeader: FC<DialogCommonProps>;
export declare const DialogSubHeader: FC<DialogCommonProps>;
export declare const DialogFooter: FC<DialogCommonProps>;
export declare const DialogLabel: FC<DialogCommonProps>;
export declare const DialogBodyText: FC<DialogCommonProps>;
export declare const DialogBody: FC<DialogCommonProps>;
export declare const DialogControlsSection: FC<DialogCommonProps>;
export declare const DialogControlsSectionHeader: FC<DialogCommonProps>;
export declare const DialogButtonPrimary: FC<DialogButtonProps>;
export declare const DialogButtonSecondary: FC<DialogButtonProps>;
export declare const DialogButton: FC<DialogButtonProps>;
